==> igniteui-react-charts-16.6.4.tgz: package/ES5/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
var PriceVolumeTrendIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.get_p3 = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "p3", {
        get: function () {
            return this.get_p3();
        },
        enumerable: true,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_qg = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "qg", {
        get: function () {
            return this.get_qg();
        },
        enumerable: true,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };

==> igniteui-react-charts-16.6.8.tgz: package/ES5/PriceVolumeTrendIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { PriceVolumeTrendIndicatorStrategy } from "./PriceVolumeTrendIndicatorStrategy";
import { markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var PriceVolumeTrendIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PriceVolumeTrendIndicator, _super);
    function PriceVolumeTrendIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PriceVolumeTrendIndicator.prototype.get_p5 = function () {
        return new PriceVolumeTrendIndicatorStrategy();
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    PriceVolumeTrendIndicator.prototype.get_qi = function () {
        return PriceVolumeTrendIndicator.$;
    };
    Object.defineProperty(PriceVolumeTrendIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    PriceVolumeTrendIndicator.$t = markType(PriceVolumeTrendIndicator, 'PriceVolumeTrendIndicator', StrategyBasedIndicator.$);
    return PriceVolumeTrendIndicator;
}(StrategyBasedIndicator));
export { PriceVolumeTrendIndicator };
